jactorch.parallel
=================

.. automodule:: jactorch.parallel

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   comm
   data_parallel
   dict_gather
   replicate
   replication_callback
   user_scattered









